@@ -130,4 +130,22 @@ def fis_preprocessing_ranking_tot(rank_mi, rank_rfe,rank_per,modo='tabla'):
     if modo == 'tabla':
         return(ranking_tot)
     else:
-        ranking_tot.set_index('variable').puntos.sort_values(ascending = False).plot.barh(figsize = (8,10));
\ No newline at end of file
+        ranking_tot.set_index('variable').puntos.sort_values(ascending = False).plot.barh(figsize = (8,10));
+        
+def fis_outliers_standard_desv(variable, x = 4):
+    """
+    Dada una variable sacamos los índices de un Dataframe para aquellos registors que su valor 
+    esté en un umbral de la media mas/menos x veces la desviación estándard de la muestra
+    por defecto es 4 veces.
+    """
+    #sacamos los nulos por ahora
+    variable = variable.dropna()
+    #calculamos los límites
+    media = np.mean(variable)
+    sd = np.std(variable)
+    umbral = sd * x
+    lim_inf = media - umbral
+    lim_sup = media + umbral
+    #encontramos los índices de los que están fuera de los límites
+    indices = [indice for indice,valor in variable.items() if valor < lim_inf or valor > lim_sup]
+    return(indices)
\ No newline at end of file
